@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -35,23 +35,57 @@
 #include "LogFactory.h"
 #include "SimpleLogger.h"
 #include "a2io.h"
+#include "prefs.h"
 
-string LogFactory::filename = DEV_NULL;
-Logger* LogFactory::logger = NULL;
+namespace aria2 {
+
+std::string LogFactory::filename = DEV_NULL;
+Logger* LogFactory::logger = 0;
+bool LogFactory::_consoleOutput = true;
+Logger::LEVEL LogFactory::_logLevel = Logger::DEBUG;
 
 Logger* LogFactory::getInstance() {
-  if(logger == NULL) {
+  if(!logger) {
     SimpleLogger* slogger = new SimpleLogger();
-    slogger->openFile(filename);
-    slogger->setStdout(Logger::NOTICE, true);
-    slogger->setStdout(Logger::WARN, true);
-    slogger->setStdout(Logger::ERROR, true);
+    if(filename != DEV_NULL) {
+      // don't open file DEV_NULL for performance sake.
+      // This avoids costly unecessary message formatting and write.
+      slogger->openFile(filename);
+    }
+    slogger->setLogLevel(_logLevel);
+    if(_consoleOutput) {
+      slogger->setStdoutLogLevel(Logger::NOTICE, true);
+      slogger->setStdoutLogLevel(Logger::WARN, true);
+      slogger->setStdoutLogLevel(Logger::ERROR, true);
+    }
     logger = slogger;
   }
   return logger;
 }
 
+void LogFactory::setLogLevel(Logger::LEVEL level)
+{
+  _logLevel = level;
+}
+
+void LogFactory::setLogLevel(const std::string& level)
+{
+  if(level == V_DEBUG) {
+    _logLevel = Logger::DEBUG;
+  } else if(level == V_INFO) {
+    _logLevel = Logger::INFO;
+  } else if(level == V_NOTICE) {
+    _logLevel = Logger::NOTICE;
+  } else if(level == V_WARN) {
+    _logLevel = Logger::WARN;
+  } else if(level == V_ERROR) {
+    _logLevel = Logger::ERROR;
+  }
+}
+
 void LogFactory::release() {
   delete logger;
-  logger = NULL;
+  logger = 0;
 }
+
+} // namespace aria2
