@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -33,6 +33,10 @@
  */
 /* copyright --> */
 #include "MetalinkParserController.h"
+
+#include <algorithm>
+#include <vector>
+
 #include "Metalinker.h"
 #include "MetalinkEntry.h"
 #include "MetalinkResource.h"
@@ -45,7 +49,7 @@
 # include "messageDigest.h"
 #endif // ENABLE_MESSAGE_DIGEST
 #include "Signature.h"
-#include <algorithm>
+#include "util.h"
 
 namespace aria2 {
 
@@ -57,11 +61,6 @@ MetalinkParserController::MetalinkParserController():
 
 MetalinkParserController::~MetalinkParserController() {}
 
-SharedHandle<Metalinker> MetalinkParserController::getResult() const
-{
-  return _metalinker;
-}
-
 void MetalinkParserController::newEntryTransaction()
 {
   _tEntry.reset(new MetalinkEntry());
@@ -77,10 +76,14 @@ void MetalinkParserController::setFileNameOfEntry(const std::string& filename)
   if(_tEntry.isNull()) {
     return;
   }
+  std::vector<std::string> elements;
+  util::split(filename, std::back_inserter(elements), "/");
+  std::string path = util::joinPath(elements.begin(), elements.end());
+
   if(_tEntry->file.isNull()) {
-    _tEntry->file.reset(new FileEntry(filename, 0, 0));
+    _tEntry->file.reset(new FileEntry(path, 0, 0));
   } else {
-    _tEntry->file->setPath(filename);
+    _tEntry->file->setPath(path);
   }
 }
 
@@ -367,7 +370,7 @@ void MetalinkParserController::commitChunkChecksumTransaction()
     std::sort(_tempChunkChecksums.begin(), _tempChunkChecksums.end(), Ascend1st<std::pair<size_t, std::string> >());
     std::deque<std::string> checksums;
     std::transform(_tempChunkChecksums.begin(), _tempChunkChecksums.end(),
-		   std::back_inserter(checksums), select2nd<std::pair<size_t, std::string> >());
+                   std::back_inserter(checksums), select2nd<std::pair<size_t, std::string> >());
     _tChunkChecksum->setChecksums(checksums);
     _tEntry->chunkChecksum = _tChunkChecksum;
   }
