@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -36,69 +36,107 @@
 #define _D_PEER_STAT_H_
 
 #include "common.h"
+
+#include <string>
+
 #include "SpeedCalc.h"
 #include "SharedHandle.h"
+#include "Command.h"
+
+namespace aria2 {
 
 class PeerStat {
 public:
   enum STATUS {
     IDLE,
     ACTIVE,
-    REQUEST_IDLE,
   };
 private:
-  int32_t cuid;
+  cuid_t cuid;
+  std::string _hostname;
+  std::string _protocol;
   SpeedCalc downloadSpeed;
   SpeedCalc uploadSpeed;
   Time downloadStartTime;
   PeerStat::STATUS status;
+  unsigned int _avgDownloadSpeed;
+  unsigned int _avgUploadSpeed;
+  uint64_t _sessionDownloadLength;
+  uint64_t _sessionUploadLength;
 public:
 
-  PeerStat(int32_t cuid = 0):cuid(cuid), status(PeerStat::IDLE) {}
+  PeerStat(cuid_t cuid, const std::string& hostname,
+           const::std::string& protocol):
+    cuid(cuid),
+    _hostname(hostname),
+    _protocol(protocol),
+    status(PeerStat::IDLE),
+    _avgDownloadSpeed(0),
+    _avgUploadSpeed(0),
+    _sessionDownloadLength(0),
+    _sessionUploadLength(0) {}
+
+  PeerStat(cuid_t cuid = 0):cuid(cuid), status(PeerStat::IDLE),
+                            _avgDownloadSpeed(0),
+                            _avgUploadSpeed(0),
+                            _sessionDownloadLength(0),
+                            _sessionUploadLength(0) {}
 
   ~PeerStat() {}
 
   /**
    * Returns current download speed in byte per sec.
    */
-  int32_t calculateDownloadSpeed() {
+  unsigned int calculateDownloadSpeed() {
     return downloadSpeed.calculateSpeed();
   }
 
-  int32_t calculateDownloadSpeed(const struct timeval& now) {
+  unsigned int calculateDownloadSpeed(const struct timeval& now) {
     return downloadSpeed.calculateSpeed(now);
   }
 
-  int32_t calculateUploadSpeed() {
+  unsigned int calculateAvgDownloadSpeed() {
+    _avgDownloadSpeed = downloadSpeed.calculateAvgSpeed();
+    return _avgDownloadSpeed;
+  }
+
+  unsigned int calculateUploadSpeed() {
     return uploadSpeed.calculateSpeed();
   }
 
-  int32_t calculateUploadSpeed(const struct timeval& now) {
+  unsigned int calculateUploadSpeed(const struct timeval& now) {
     return uploadSpeed.calculateSpeed(now);
   }
 
-  void updateDownloadLength(int32_t bytes) {
+  unsigned int calculateAvgUploadSpeed() {
+    _avgUploadSpeed = uploadSpeed.calculateAvgSpeed();
+    return _avgUploadSpeed;
+  }
+
+  void updateDownloadLength(size_t bytes) {
     downloadSpeed.update(bytes);
+    _sessionDownloadLength += bytes;
   }
 
-  void updateUploadLength(int32_t bytes) {
+  void updateUploadLength(size_t bytes) {
     uploadSpeed.update(bytes);
+    _sessionUploadLength += bytes;
   }
 
-  int32_t getMaxDownloadSpeed() const {
+  unsigned int getMaxDownloadSpeed() const {
     return downloadSpeed.getMaxSpeed();
   }
 
-  int32_t getMaxUploadSpeed() const {
+  unsigned int getMaxUploadSpeed() const {
     return uploadSpeed.getMaxSpeed();
   }
 
-  int32_t getAvgDownloadSpeed() const {
-    return downloadSpeed.getAvgSpeed();
+  unsigned int getAvgDownloadSpeed() const {
+    return _avgDownloadSpeed;
   }
 
-  int32_t getAvgUploadSpeed() const {
-    return uploadSpeed.getAvgSpeed();
+  unsigned int getAvgUploadSpeed() const {
+    return _avgUploadSpeed;
   }
 
   void reset() {
@@ -114,13 +152,11 @@ public:
   }
 
   void downloadStop() {
+    calculateAvgDownloadSpeed();
+    calculateAvgUploadSpeed();
     status = PeerStat::IDLE;
   }
 
-  void requestIdle() {
-    status = PeerStat::REQUEST_IDLE;
-  }
-
   const Time& getDownloadStartTime() const {
     return downloadStartTime;
   }
@@ -129,11 +165,38 @@ public:
     return status;
   }
 
-  int32_t getCuid() const {
+  cuid_t getCuid() const {
     return cuid;
   }
+
+  const std::string& getHostname() const
+  {
+    return _hostname;
+  }
+
+  const std::string& getProtocol() const
+  {
+    return _protocol;
+  }
+
+  uint64_t getSessionDownloadLength() const
+  {
+    return _sessionDownloadLength;
+  }
+
+  uint64_t getSessionUploadLength() const
+  {
+    return _sessionUploadLength;
+  }
+
+  void addSessionDownloadLength(uint64_t length)
+  {
+    _sessionDownloadLength += length;
+  }
 };
 
 typedef SharedHandle<PeerStat> PeerStatHandle;
 
+} // namespace aria2
+
 #endif // _D_PEER_STAT_H_
