@@ -150,13 +150,6 @@ RequestGroup::RequestGroup(const SharedHandle<Option>& option):
 
 RequestGroup::~RequestGroup() {}
 
-const SegmentManHandle& RequestGroup::initSegmentMan()
-{
-  _segmentMan = _segmentManFactory->createNewInstance(_downloadContext,
-                                                      _pieceStorage);
-  return _segmentMan;
-}
-
 bool RequestGroup::downloadFinished() const
 {
   if(_pieceStorage.isNull()) {
@@ -445,6 +438,7 @@ void RequestGroup::processCheckIntegrityEntry(std::deque<Command*>& commands,
 
 void RequestGroup::initPieceStorage()
 {
+  SharedHandle<PieceStorage> tempPieceStorage;
   if(_downloadContext->knowsTotalLength()) {
 #ifdef ENABLE_BITTORRENT
     SharedHandle<DefaultPieceStorage> ps
@@ -483,17 +477,21 @@ void RequestGroup::initPieceStorage()
     if(!_diskWriterFactory.isNull()) {
       ps->setDiskWriterFactory(_diskWriterFactory);
     }
-    _pieceStorage = ps;
+    tempPieceStorage = ps;
   } else {
     UnknownLengthPieceStorageHandle ps
       (new UnknownLengthPieceStorage(_downloadContext, _option.get()));
     if(!_diskWriterFactory.isNull()) {
       ps->setDiskWriterFactory(_diskWriterFactory);
     }
-    _pieceStorage = ps;
+    tempPieceStorage = ps;
   }
-  _pieceStorage->initStorage();
-  initSegmentMan();
+  tempPieceStorage->initStorage();
+  SharedHandle<SegmentMan> tempSegmentMan =
+    _segmentManFactory->createNewInstance(_downloadContext, tempPieceStorage);
+
+  _pieceStorage = tempPieceStorage;
+  _segmentMan = tempSegmentMan;
 }
 
 bool RequestGroup::downloadFinishedByFileLength()
@@ -618,7 +616,7 @@ bool RequestGroup::tryAutoFileRenaming()
     return false;
   }
   for(unsigned int i = 1; i < 10000; ++i) {
-    File newfile(strconcat(filepath, ".", util::uitos(i)));
+    File newfile(strconcat(filepath, A2STR::DOT_C, util::uitos(i)));
     File ctrlfile(newfile.getPath()+DefaultBtProgressInfoFile::getSuffix());
     if(!newfile.exists() || (newfile.exists() && ctrlfile.exists())) {
       _downloadContext->getFirstFileEntry()->setPath(newfile.getPath());
@@ -1026,7 +1024,8 @@ void RequestGroup::increaseAndValidateFileNotFoundCount()
   ++_fileNotFoundCount;
   const unsigned int maxCount = _option->getAsInt(PREF_MAX_FILE_NOT_FOUND);
   if(maxCount > 0 && _fileNotFoundCount >= maxCount &&
-     _segmentMan->calculateSessionDownloadLength() == 0) {
+     (_segmentMan.isNull() ||
+      _segmentMan->calculateSessionDownloadLength() == 0)) {
     throw DOWNLOAD_FAILURE_EXCEPTION2
       (StringFormat("Reached max-file-not-found count=%u", maxCount).str(),
        downloadresultcode::MAX_FILE_NOT_FOUND);
