@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -33,41 +33,75 @@
  */
 /* copyright --> */
 #include "SeedCheckCommand.h"
+#include "DownloadEngine.h"
+#include "BtRuntime.h"
+#include "PieceStorage.h"
+#include "Logger.h"
+#include "SeedCriteria.h"
 #include "message.h"
+#include "RequestGroup.h"
+#include "DownloadContext.h"
+
+namespace aria2 {
 
 SeedCheckCommand::SeedCheckCommand(int cuid,
-				   RequestGroup* requestGroup,
-				   DownloadEngine* e,
-				   const BtContextHandle& btContext,
-				   SeedCriteriaHandle seedCriteria)
+                                   RequestGroup* requestGroup,
+                                   DownloadEngine* e,
+                                   const SeedCriteriaHandle& seedCriteria)
   :Command(cuid),
-   BtContextAwareCommand(btContext),
-   RequestGroupAware(requestGroup),
+   _requestGroup(requestGroup),
    e(e),
    seedCriteria(seedCriteria),
-   checkStarted(false) {}
+   checkStarted(false)
+{
+  setStatusRealtime();
+  _requestGroup->increaseNumCommand();
+}
+
+SeedCheckCommand::~SeedCheckCommand()
+{
+  _requestGroup->decreaseNumCommand();
+}
 
 bool SeedCheckCommand::execute() {
-  if(btRuntime->isHalt()) {
+  if(_btRuntime->isHalt()) {
     return true;
   }
   if(!seedCriteria.get()) {
     return false;
   }
-  if(checkPoint.elapsed(1)) {
-    if(!checkStarted) {
-      if(pieceStorage->downloadFinished()) {
-	checkStarted = true;
-	seedCriteria->reset();
-      }
+  if(!checkStarted) {
+    if(_pieceStorage->downloadFinished()) {
+      checkStarted = true;
+      seedCriteria->reset();
     }
-    if(checkStarted) {
-      if(seedCriteria->evaluate()) {
-	logger->notice(MSG_SEEDING_END);
-	btRuntime->setHalt(true);
-      }
+  }
+  if(checkStarted) {
+    if(seedCriteria->evaluate()) {
+      logger->notice(MSG_SEEDING_END);
+      _btRuntime->setHalt(true);
     }
   }
   e->commands.push_back(this);
   return false;
 }
+
+void SeedCheckCommand::setSeedCriteria
+(const SharedHandle<SeedCriteria>& seedCriteria)
+{
+  this->seedCriteria = seedCriteria;
+}
+
+void SeedCheckCommand::setBtRuntime(const SharedHandle<BtRuntime>& btRuntime)
+{
+  _btRuntime = btRuntime;
+}
+
+void SeedCheckCommand::setPieceStorage
+(const SharedHandle<PieceStorage>& pieceStorage)
+{
+  _pieceStorage = pieceStorage;
+}
+
+
+} // namespace aria2
