@@ -13,7 +13,7 @@
 #include "Option.h"
 #include "array_fun.h"
 #include "CookieStorage.h"
-#include "Util.h"
+#include "util.h"
 #include "AuthConfig.h"
 
 namespace aria2 {
@@ -28,6 +28,7 @@ class HttpRequestTest : public CppUnit::TestFixture {
   CPPUNIT_TEST(testCreateRequest_with_cookie);
   CPPUNIT_TEST(testCreateRequest_query);
   CPPUNIT_TEST(testCreateRequest_head);
+  CPPUNIT_TEST(testCreateRequest_ipv6LiteralAddr);
   CPPUNIT_TEST(testCreateProxyRequest);
   CPPUNIT_TEST(testIsRangeSatisfied);
   CPPUNIT_TEST(testUserAgent);
@@ -43,7 +44,7 @@ public:
   {
     _option.reset(new Option());
     _option->put(PREF_HTTP_AUTH_CHALLENGE, V_TRUE);
-    _authConfigFactory.reset(new AuthConfigFactory(_option.get()));
+    _authConfigFactory.reset(new AuthConfigFactory());
   }
 
   void testGetStartByte();
@@ -53,6 +54,7 @@ public:
   void testCreateRequest_with_cookie();
   void testCreateRequest_query();
   void testCreateRequest_head();
+  void testCreateRequest_ipv6LiteralAddr();
   void testCreateProxyRequest();
   void testIsRangeSatisfied();
   void testUserAgent();
@@ -69,13 +71,14 @@ void HttpRequestTest::testGetStartByte()
   HttpRequest httpRequest;
   SharedHandle<Piece> p(new Piece(1, 1024));
   SharedHandle<Segment> segment(new PiecedSegment(1024, p));
+  SharedHandle<FileEntry> fileEntry(new FileEntry("file", 1024*10, 0));
 
   CPPUNIT_ASSERT_EQUAL((off_t)0LL, httpRequest.getStartByte());
 
   httpRequest.setSegment(segment);
+  httpRequest.setFileEntry(fileEntry);
   
   CPPUNIT_ASSERT_EQUAL((off_t)1024LL, httpRequest.getStartByte());
-
 }
 
 void HttpRequestTest::testGetEndByte()
@@ -87,6 +90,7 @@ void HttpRequestTest::testGetEndByte()
   HttpRequest httpRequest;
   SharedHandle<Piece> piece(new Piece(index, length));
   SharedHandle<Segment> segment(new PiecedSegment(segmentLength, piece));
+  SharedHandle<FileEntry> fileEntry(new FileEntry("file", segmentLength*10, 0));
 
   CPPUNIT_ASSERT_EQUAL((off_t)0LL, httpRequest.getEndByte());
 
@@ -99,10 +103,16 @@ void HttpRequestTest::testGetEndByte()
   request->setPipeliningHint(true);
 
   httpRequest.setRequest(request);
+  httpRequest.setFileEntry(fileEntry);
 
   CPPUNIT_ASSERT_EQUAL((off_t)(segmentLength*index+length-1),
-		       httpRequest.getEndByte());
+                       httpRequest.getEndByte());
 
+  // The end byte of FileEntry are placed inside segment
+  fileEntry->setLength(segmentLength+100);
+
+  CPPUNIT_ASSERT_EQUAL((off_t)(segmentLength*index+100-1),
+                       httpRequest.getEndByte());
 
   request->setPipeliningHint(false);
 
@@ -120,12 +130,14 @@ void HttpRequestTest::testCreateRequest()
 
   p.reset(new Piece(0, 1024));
   SharedHandle<Segment> segment(new PiecedSegment(1024, p));
+  SharedHandle<FileEntry> fileEntry(new FileEntry("file", 1024*1024*10, 0));
 
   HttpRequest httpRequest;
   httpRequest.disableContentEncoding();
   httpRequest.setRequest(request);
   httpRequest.setSegment(segment);
-  httpRequest.setAuthConfigFactory(_authConfigFactory);
+  httpRequest.setFileEntry(fileEntry);
+  httpRequest.setAuthConfigFactory(_authConfigFactory, _option.get());
 
   // remove "Connection: close" and add end byte range
   request->setPipeliningHint(true);  
@@ -226,7 +238,8 @@ void HttpRequestTest::testCreateRequest()
   _option->put(PREF_HTTP_USER, "aria2user");
   _option->put(PREF_HTTP_PASSWD, "aria2passwd");
 
-  CPPUNIT_ASSERT(_authConfigFactory->activateBasicCred("localhost", "/"));
+  CPPUNIT_ASSERT(_authConfigFactory->activateBasicCred
+                 ("localhost", "/", _option.get()));
 
   expectedText = "GET /archives/aria2-1.0.0.tar.bz2 HTTP/1.1\r\n"
     "User-Agent: aria2\r\n"
@@ -243,7 +256,7 @@ void HttpRequestTest::testCreateRequest()
   // enable http proxy auth
   SharedHandle<Request> proxyRequest(new Request());
   CPPUNIT_ASSERT(proxyRequest->setUrl
-		 ("http://aria2proxyuser:aria2proxypasswd@localhost:9000"));
+                 ("http://aria2proxyuser:aria2proxypasswd@localhost:9000"));
   httpRequest.setProxyRequest(proxyRequest);
 
   expectedText = "GET http://localhost:8080/archives/aria2-1.0.0.tar.bz2 HTTP/1.1\r\n"
@@ -297,24 +310,27 @@ void HttpRequestTest::testCreateRequest()
 
 void HttpRequestTest::testCreateRequest_ftp()
 {
-   _option->put(PREF_FTP_USER, "aria2user");
-   _option->put(PREF_FTP_PASSWD, "aria2passwd");
+  _option->put(PREF_FTP_USER, "aria2user");
+  _option->put(PREF_FTP_PASSWD, "aria2passwd");
 
   SharedHandle<Request> request(new Request());
   request->setUrl("ftp://localhost:8080/archives/aria2-1.0.0.tar.bz2");
 
   SharedHandle<Request> proxyRequest(new Request());
   CPPUNIT_ASSERT(proxyRequest->setUrl
-		 ("http://localhost:9000"));
+                 ("http://localhost:9000"));
 
   HttpRequest httpRequest;
   SharedHandle<Piece> p(new Piece(0, 1024*1024));
   SharedHandle<Segment> segment
     (new PiecedSegment(1024*1024, p));
+  SharedHandle<FileEntry> fileEntry(new FileEntry("file", 1024*1024*10, 0));
+
   httpRequest.disableContentEncoding();
   httpRequest.setRequest(request);
   httpRequest.setSegment(segment);
-  httpRequest.setAuthConfigFactory(_authConfigFactory);
+  httpRequest.setFileEntry(fileEntry);
+  httpRequest.setAuthConfigFactory(_authConfigFactory, _option.get());
   httpRequest.setProxyRequest(proxyRequest);
 
   std::string expectedText =
@@ -334,7 +350,7 @@ void HttpRequestTest::testCreateRequest_ftp()
 
   // test proxy authorization
   CPPUNIT_ASSERT(proxyRequest->setUrl
-		 ("http://aria2proxyuser:aria2proxypasswd@localhost:9000"));
+                 ("http://aria2proxyuser:aria2proxypasswd@localhost:9000"));
 
   expectedText =
     "GET ftp://aria2user@localhost:8080/archives/aria2-1.0.0.tar.bz2"
@@ -360,6 +376,7 @@ void HttpRequestTest::testCreateRequest_with_cookie()
   SharedHandle<Piece> p(new Piece(0, 1024*1024));
   SharedHandle<Segment> segment
     (new PiecedSegment(1024*1024, p));
+  SharedHandle<FileEntry> fileEntry(new FileEntry("file", 1024*1024*10, 0));
 
   Cookie cookie1("name1", "value1", "/archives", "localhost", false);
   Cookie cookie2("name2", "value2", "/archives/download", "localhost", false);
@@ -377,8 +394,9 @@ void HttpRequestTest::testCreateRequest_with_cookie()
   httpRequest.disableContentEncoding();
   httpRequest.setRequest(request);
   httpRequest.setSegment(segment);
+  httpRequest.setFileEntry(fileEntry);
   httpRequest.setCookieStorage(st);
-  httpRequest.setAuthConfigFactory(_authConfigFactory);
+  httpRequest.setAuthConfigFactory(_authConfigFactory, _option.get());
 
   std::string expectedText = "GET /archives/aria2-1.0.0.tar.bz2 HTTP/1.1\r\n"
     "User-Agent: aria2\r\n"
@@ -421,7 +439,7 @@ void HttpRequestTest::testCreateRequest_with_cookie()
   CPPUNIT_ASSERT_EQUAL(expectedText, httpRequest.createRequest());
 
   request->setUrl("https://www.aria2.org/archives/download/"
-		  "aria2-1.0.0.tar.bz2");
+                  "aria2-1.0.0.tar.bz2");
 
   expectedText = "GET /archives/download/aria2-1.0.0.tar.bz2 HTTP/1.1\r\n"
     "User-Agent: aria2\r\n"
@@ -444,7 +462,7 @@ void HttpRequestTest::testCreateRequest_query()
   HttpRequest httpRequest;
   httpRequest.disableContentEncoding();
   httpRequest.setRequest(request);
-  httpRequest.setAuthConfigFactory(_authConfigFactory);
+  httpRequest.setAuthConfigFactory(_authConfigFactory, _option.get());
 
   std::string expectedText =
     "GET /wiki?id=9ad5109a-b8a5-4edf-9373-56a1c34ae138 HTTP/1.1\r\n"
@@ -467,12 +485,12 @@ void HttpRequestTest::testCreateRequest_head()
 
   HttpRequest httpRequest;
   httpRequest.setRequest(request);
-  httpRequest.setAuthConfigFactory(_authConfigFactory);
+  httpRequest.setAuthConfigFactory(_authConfigFactory, _option.get());
   
   std::stringstream result(httpRequest.createRequest());
   std::string line;
   CPPUNIT_ASSERT(getline(result, line));
-  Util::trimSelf(line);
+  util::trimSelf(line);
   CPPUNIT_ASSERT_EQUAL(std::string("HEAD /aria2-1.0.0.tar.bz2 HTTP/1.1"), line);
 }
 
@@ -527,7 +545,7 @@ void HttpRequestTest::testCreateProxyRequest()
 
   // test proxy authorization
   CPPUNIT_ASSERT(proxyRequest->setUrl
-		 ("http://aria2proxyuser:aria2proxypasswd@localhost:9000"));
+                 ("http://aria2proxyuser:aria2proxypasswd@localhost:9000"));
 
   expectedText = "CONNECT localhost:80 HTTP/1.1\r\n"
     "User-Agent: aria2\r\n"
@@ -547,11 +565,13 @@ void HttpRequestTest::testIsRangeSatisfied()
   request->setPipeliningHint(false); // default: false
   SharedHandle<Piece> p(new Piece(0, 1024*1024));
   SharedHandle<Segment> segment(new PiecedSegment(1024*1024, p));
+  SharedHandle<FileEntry> fileEntry(new FileEntry("file", 0, 0));
 
   HttpRequest httpRequest;
 
   httpRequest.setRequest(request);
   httpRequest.setSegment(segment);
+  httpRequest.setFileEntry(fileEntry);
 
   SharedHandle<Range> range(new Range());
 
@@ -569,11 +589,11 @@ void HttpRequestTest::testIsRangeSatisfied()
 
   CPPUNIT_ASSERT(httpRequest.isRangeSatisfied(range));
 
-  httpRequest.setEntityLength(entityLength-1);
+  fileEntry->setLength(entityLength-1);
 
   CPPUNIT_ASSERT(!httpRequest.isRangeSatisfied(range));
 
-  httpRequest.setEntityLength(entityLength);
+  fileEntry->setLength(entityLength);
 
   CPPUNIT_ASSERT(httpRequest.isRangeSatisfied(range));
 
@@ -582,13 +602,13 @@ void HttpRequestTest::testIsRangeSatisfied()
   CPPUNIT_ASSERT(!httpRequest.isRangeSatisfied(range));
 
   range.reset(new Range(segment->getPosition(),
-			segment->getPosition()+segment->getLength()-1,
-			entityLength));
+                        segment->getPosition()+segment->getLength()-1,
+                        entityLength));
 
   CPPUNIT_ASSERT(httpRequest.isRangeSatisfied(range));
 
   range.reset(new Range(0, segment->getPosition()+segment->getLength()-1,
-			entityLength));
+                        entityLength));
 
   CPPUNIT_ASSERT(!httpRequest.isRangeSatisfied(range));
 }
@@ -598,15 +618,15 @@ void HttpRequestTest::testUserAgent()
   SharedHandle<Request> request(new Request());
   request->setUrl("http://localhost:8080/archives/aria2-1.0.0.tar.bz2");
 
-  SharedHandle<Piece> p(new Piece(0, 1024));
-  SharedHandle<Segment> segment(new PiecedSegment(1024, p));
+  //SharedHandle<Piece> p(new Piece(0, 1024));
+  //SharedHandle<Segment> segment(new PiecedSegment(1024, p));
 
   HttpRequest httpRequest;
   httpRequest.disableContentEncoding();
   httpRequest.setRequest(request);
-  httpRequest.setSegment(segment);
+  //httpRequest.setSegment(segment);
   httpRequest.setUserAgent("aria2 (Linux)");
-  httpRequest.setAuthConfigFactory(_authConfigFactory);
+  httpRequest.setAuthConfigFactory(_authConfigFactory, _option.get());
 
   std::string expectedText = "GET /archives/aria2-1.0.0.tar.bz2 HTTP/1.1\r\n"
     "User-Agent: aria2 (Linux)\r\n"
@@ -641,7 +661,7 @@ void HttpRequestTest::testAddHeader()
   HttpRequest httpRequest;
   httpRequest.disableContentEncoding();
   httpRequest.setRequest(request);
-  httpRequest.setAuthConfigFactory(_authConfigFactory);
+  httpRequest.setAuthConfigFactory(_authConfigFactory, _option.get());
   httpRequest.addHeader("X-ARIA2: v0.13\nX-ARIA2-DISTRIBUTE: enabled\n");
 
   std::string expectedText = "GET /archives/aria2-1.0.0.tar.bz2 HTTP/1.1\r\n"
@@ -661,7 +681,7 @@ void HttpRequestTest::testAddHeader()
 void HttpRequestTest::testAddAcceptType()
 {
   std::string acceptTypes[] = { "cream/custard",
-				"muffin/chocolate" };
+                                "muffin/chocolate" };
 
   SharedHandle<Request> request(new Request());
   request->setUrl("http://localhost/archives/aria2-1.0.0.tar.bz2");
@@ -669,9 +689,9 @@ void HttpRequestTest::testAddAcceptType()
   HttpRequest httpRequest;
   httpRequest.disableContentEncoding();
   httpRequest.setRequest(request);
-  httpRequest.setAuthConfigFactory(_authConfigFactory);
+  httpRequest.setAuthConfigFactory(_authConfigFactory, _option.get());
   httpRequest.addAcceptType(&acceptTypes[0],
-			    &acceptTypes[arrayLength(acceptTypes)]);
+                            &acceptTypes[arrayLength(acceptTypes)]);
 
   std::string expectedText =
     "GET /archives/aria2-1.0.0.tar.bz2 HTTP/1.1\r\n"
@@ -693,7 +713,7 @@ void HttpRequestTest::testEnableAcceptEncoding()
 
   HttpRequest httpRequest;
   httpRequest.setRequest(request);
-  httpRequest.setAuthConfigFactory(_authConfigFactory);
+  httpRequest.setAuthConfigFactory(_authConfigFactory, _option.get());
 
   std::string acceptEncodings;
 #ifdef HAVE_LIBZ
@@ -717,4 +737,23 @@ void HttpRequestTest::testEnableAcceptEncoding()
   CPPUNIT_ASSERT_EQUAL(expectedText, httpRequest.createRequest());
 }
 
+void HttpRequestTest::testCreateRequest_ipv6LiteralAddr()
+{
+  SharedHandle<Request> request(new Request());
+  request->setUrl("http://[::1]/path");
+  HttpRequest httpRequest;
+  httpRequest.disableContentEncoding();
+  httpRequest.setRequest(request);
+  httpRequest.setAuthConfigFactory(_authConfigFactory, _option.get());
+
+  CPPUNIT_ASSERT(httpRequest.createRequest().find("Host: [::1]") != std::string::npos);
+
+  SharedHandle<Request> proxy(new Request());
+  proxy->setUrl("http://proxy");
+  httpRequest.setProxyRequest(proxy);
+  std::string proxyRequest = httpRequest.createProxyRequest();
+  CPPUNIT_ASSERT(proxyRequest.find("Host: [::1]:80") != std::string::npos);
+  CPPUNIT_ASSERT(proxyRequest.find("CONNECT [::1]:80 ") != std::string::npos);
+}
+
 } // namespace aria2
